#include "dbext.h"   /* SHORT, YMDHMS_TIME_TYPE */

typedef struct
{
   int year, julian_day, hour, minute, second;        /* 2-digit year only */
} JD_TIME_TYPE;

#if PROTOTYPE_ALLOWED
int ymdhms_to_jdtime(JD_TIME_TYPE *j, YMDHMS_TIME_TYPE *y);
double jd_to_ddtime(JD_TIME_TYPE *j, int year_base);
int jd_to_ymdhms_time(YMDHMS_TIME_TYPE *y, JD_TIME_TYPE *j);
int jd_timcmp(JD_TIME_TYPE *t1, JD_TIME_TYPE *t2);
#else
int ymdhms_to_jdtime();
double jd_to_ddtime();
int jd_to_ymdhms_time();
int jd_timcmp();
#endif
